﻿using Microsoft.AspNetCore.Mvc;
using SushiBarContracts.BindingModels;
using SushiBarContracts.BusinessLogicsContracts;
using SushiBarContracts.SearchModels;
using SushiBarContracts.ViewModels;

namespace SushiBarRestApi.Controllers
{
    [Route("api/[controller]/[action]")]
    [ApiController]
    public class MainController : Controller
    {
        private readonly ILogger _logger;
        private readonly IOrderLogic _order;
        private readonly ISushiLogic _iceCream;
        public MainController(ILogger<MainController> logger, IOrderLogic order, ISushiLogic iceCream)
        {
            _logger = logger;
            _order = order;
            _iceCream = iceCream;
        }
        [HttpGet]
        public List<SushiViewModel>? GetSushiList()
        {
            try
            {
                return _iceCream.ReadList(null);
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка получения списка мороженного");
                throw;
            }
        }
        [HttpGet]
        public SushiViewModel? GetSushi(int iceCreamId)
        {
            try
            {
                return _iceCream.ReadElement(new SushiSearchModel
                {
                    Id = iceCreamId
				});
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка получения продукта по id={Id}", iceCreamId);
                throw;
            }
        }
        [HttpGet]
        public List<OrderViewModel>? GetOrders(int clientId)
        {
            try
            {
                return _order.ReadList(new OrderSearchModel
                {
                    ClientId = clientId
                });
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка получения списка заказов клиента id ={ Id}", clientId);
            throw;
            }
        }
        [HttpPost]
        public void CreateOrder(OrderBindingModel model)
        {
            try
            {
                _order.CreateOrder(model);
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка создания заказа");
                throw;
            }
        }
    }
}
